Learn R Programming

istat (version 1.1.1)

shinyIstat: shinyIstat

Description

A graphic interface that makes searching, downloading and filtering data sets from Istat easier. Call shinyIstat() to get started. This shinyApp was built using the same functions of istat package but they have been adapted for the shiny. You will find additional information and help inside the app.

Usage

shinyIstat()

Arguments

Value

It opens the app.

Examples

Run this code
if(interactive()) {
  shinyIstat()
}

Run the code above in your browser using DataLab