- id_dataset
Data set id.
- start_period
Time value for the start (NULL by default).
- end_period
Time value for the end (NULL bu default).
- recent
FALSE by default, if TRUE, the function retrieves data from last 10 years.
- csv
FALSE by default, if TRUE, the function saves the data set to directory as .csv.
- xlsx
FALSE by default, if TRUE, the function saves the data set to directory as .xlsx.
- lang
Language parameter for labels ("ita" for Italian, "eng" for English).
- cache
TRUE by default. If FALSE, the function retrieve the data set without caching.
- update_cache
FALSE by default. If TRUE, the cache is updated.
- compress_file
TRUE by default. It compresses the RDS file in caching.
- cache_dir
By default it saves the cache directory into the current working directory.