list_i_stat: Obtain the complete list of available data sets (source: I.Stat)
Description
Obtain the complete list of available data sets (source: I.Stat)
Usage
list_i_stat(lang = "ita")
Value
It returns the complete list of available data sets from I.Stat with their ids and names.
Arguments
- lang
language parameter for labels ("ita" for Italian, "eng" for English)