list_istatdata: Obtain the complete list of available data sets (source: IstatData)
Description
Obtain the complete list of available data sets (source: IstatData)
Usage
list_istatdata(lang = "ita")
Value
It returns the complete list of available data sets from IstatData with their ids and names.
Arguments
- lang
language parameter for labels ("ita" for Italian, "eng" for English)